@@ -53,12 +53,10 @@ class Geo_common:
         for line in data[1:]:
             for head in data[0][1:]:
                 tmp = line[data[0].index(head)]
-                if not tmp: continue                                   # 允许出现空值 , 并直接跳过
                 if head in ["group","raw_file_r1","raw_file_r2"]:      # 这三个key允许多个值, 一致使用列表元素
                     tmp = tmp.strip().split(";")                           # group , raw_file_r1 , raw_file_r2 可以输入多个值, 用 ; 分割
                     self.samples[line[0]][head] = []
                     for i in tmp:
-                        if not i: continue                             # 防止出现空值
                         self.samples[line[0]][head].append(i)
                 else:
                     self.samples[line[0]][head] = tmp
@@ -105,12 +103,10 @@ class Geo_common:
         # parameters: 流程的部分参数, 经常修改的, 比如pvalue, FDR等, dict = {key:value}
         self.parameters = {}
         for k,v in ParserXLS.fetch_col(excel, project_name, "PARAMETERS").items():
-            if not v: continue
             self.parameters[k] = v
         # pipeline_control: 流程控制参数, 如抽数据, 去污染等, dict = {key:value}
         self.pipeline_control = {}
         for k,v in ParserXLS.fetch_col(excel, project_name, "PIPELINE_CONTROL").items():
-            if not v: continue
             self.pipeline_control[k] = v
 
         #### 常用变量:
